"""
📌 این اسکریپت به‌صورت خودکار هر روز ساعت ۸ صبح وضعیت آب و هوای تهران را دریافت و به ایمیل شما ارسال می‌کند.

🔧 **پیش‌نیازها:**
1️⃣ نصب کتابخانه‌های موردنیاز:
   ```bash
   pip install requests schedule smtplib email
   ```
2️⃣ دریافت API Key از [OpenWeatherMap](https://openweathermap.org/api) و جایگذاری در متغیر `api_key`
3️⃣ استفاده از **App Password** برای Gmail (چون Google اجازه‌ی ورود مستقیم با رمز معمولی را نمی‌دهد)
"""

import requests  # برای دریافت داده‌های آب و هوا از API
import smtplib  # برای ارسال ایمیل
import schedule  # برای زمان‌بندی اجرای خودکار اسکریپت
import time  # برای کنترل اجرای دوره‌ای کد
from email.mime.text import MIMEText  # برای ایجاد محتوای متنی ایمیل
from email.mime.multipart import MIMEMultipart  # برای ترکیب بخش‌های مختلف ایمیل

# ------------------- تنظیمات ایمیل -------------------
SMTP_SERVER = "smtp.gmail.com"  # آدرس سرور SMTP برای ارسال ایمیل
SMTP_PORT = 587  # پورت SMTP برای ارسال ایمیل
SENDER_EMAIL = "your_email@gmail.com"  # آدرس ایمیل ارسال‌کننده
SENDER_PASSWORD = "your_email_password"  # رمز عبور ایمیل یا App Password
RECEIVER_EMAIL = "receiver_email@gmail.com"  # آدرس ایمیل گیرنده

# ------------------- دریافت اطلاعات آب و هوا -------------------
def get_weather():
    api_key = "your_openweathermap_api_key"  # کلید API برای دریافت اطلاعات آب و هوا
    city = "Tehran"  # نام شهر موردنظر برای گزارش آب و هوا
    url = f"http://api.openweathermap.org/data/2.5/weather?q={city}&appid={api_key}&units=metric&lang=fa"  # آدرس API برای دریافت داده‌ها

    response = requests.get(url)  # ارسال درخواست به API
    if response.status_code == 200:  # بررسی موفقیت‌آمیز بودن دریافت اطلاعات
        data = response.json()  # تبدیل پاسخ به فرمت JSON
        weather_desc = data["weather"][0]["description"]  # توضیحات وضعیت آب و هوا
        temp = data["main"]["temp"]  # دمای فعلی
        humidity = data["main"]["humidity"]  # میزان رطوبت
        wind_speed = data["wind"]["speed"]  # سرعت باد

        # بازگرداندن اطلاعات در قالب یک پیام متنی
        return f"🌤 **وضعیت آب و هوای تهران:**\n\n🔹 **دما:** {temp}°C\n💦 **رطوبت:** {humidity}%\n💨 **سرعت باد:** {wind_speed} m/s\n🌦 **وضعیت:** {weather_desc}"
    else:
        return "❌ دریافت اطلاعات آب و هوا ناموفق بود!"  # پیام خطا در صورت شکست درخواست

# ------------------- ارسال ایمیل -------------------
def send_email():
    weather_report = get_weather()  # دریافت اطلاعات آب و هوا
    
    # تنظیمات ایمیل
    msg = MIMEMultipart()  # ایجاد یک پیام چندبخشی برای ایمیل
    msg["From"] = SENDER_EMAIL  # تنظیم فرستنده ایمیل
    msg["To"] = RECEIVER_EMAIL  # تنظیم گیرنده ایمیل
    msg["Subject"] = "🌦 گزارش روزانه آب و هوای تهران"  # عنوان ایمیل

    # اضافه کردن متن گزارش آب و هوا به ایمیل
    msg.attach(MIMEText(weather_report, "plain"))

    try:
        server = smtplib.SMTP(SMTP_SERVER, SMTP_PORT)  # اتصال به سرور SMTP
        server.starttls()  # فعال کردن رمزگذاری برای امنیت بیشتر
        server.login(SENDER_EMAIL, SENDER_PASSWORD)  # ورود به حساب ایمیل ارسال‌کننده
        server.sendmail(SENDER_EMAIL, RECEIVER_EMAIL, msg.as_string())  # ارسال ایمیل
        server.quit()  # بستن اتصال به سرور
        print("✅ ایمیل با موفقیت ارسال شد!")  # نمایش پیام موفقیت
    except Exception as e:
        print(f"❌ خطا در ارسال ایمیل: {e}")  # نمایش پیام خطا در صورت بروز مشکل

# ------------------- تنظیم اجرای خودکار در ساعت ۸ صبح -------------------
schedule.every().day.at("08:00").do(send_email)  # زمان‌بندی اجرای تابع ارسال ایمیل در ساعت ۸ صبح هر روز

# اجرای مداوم برای بررسی زمان اجرا
while True:
    schedule.run_pending()  # بررسی اجرای برنامه‌ریزی شده
    time.sleep(60)  # تاخیر یک دقیقه‌ای برای بررسی مجدد
